# PyEZNaCl

A wrapper around PyNaCl to make it even easier to use.

## Description

Working with encryption is hard. PyNaCl made it a *lot* easier, but it's still kind of hard to figure out for newcomers to encryption. PyEZNaCl is a pure-Python module that gets as close to push-button cryptography as a developer can feasibly be.

## Status

The module is stable and ready for production use. Usage information can be found in the USAGE.md file in this repository.

## Building

This is a very simple module. Most people will just want to install it using pip.
